from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Security.Authentication.Web
import win32more.Windows.Win32.System.WinRT
class IWebAuthenticationBrokerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics'
    _iid_ = Guid('{2f149f1a-e673-40b5-bc22-201a6864a37b}')
    @winrt_commethod(6)
    def AuthenticateWithCallbackUriAsync(self, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions, requestUri: win32more.Windows.Foundation.Uri, callbackUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
    @winrt_commethod(7)
    def AuthenticateWithoutCallbackUriAsync(self, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions, requestUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
    @winrt_commethod(8)
    def GetCurrentApplicationCallbackUri(self) -> win32more.Windows.Foundation.Uri: ...
class IWebAuthenticationBrokerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics2'
    _iid_ = Guid('{73cdfb9e-14e7-41da-a971-aaf4410b621e}')
    @winrt_commethod(6)
    def AuthenticateAndContinue(self, requestUri: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(7)
    def AuthenticateWithCallbackUriAndContinue(self, requestUri: win32more.Windows.Foundation.Uri, callbackUri: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def AuthenticateWithCallbackUriContinuationDataAndOptionsAndContinue(self, requestUri: win32more.Windows.Foundation.Uri, callbackUri: win32more.Windows.Foundation.Uri, continuationData: win32more.Windows.Foundation.Collections.ValueSet, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions) -> Void: ...
    @winrt_commethod(9)
    def AuthenticateSilentlyAsync(self, requestUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
    @winrt_commethod(10)
    def AuthenticateSilentlyWithOptionsAsync(self, requestUri: win32more.Windows.Foundation.Uri, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
class IWebAuthenticationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.Web.IWebAuthenticationResult'
    _iid_ = Guid('{64002b4b-ede9-470a-a5cd-0323faf6e262}')
    @winrt_commethod(6)
    def get_ResponseData(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ResponseStatus(self) -> win32more.Windows.Security.Authentication.Web.WebAuthenticationStatus: ...
    @winrt_commethod(8)
    def get_ResponseErrorDetail(self) -> UInt32: ...
    ResponseData = property(get_ResponseData, None)
    ResponseErrorDetail = property(get_ResponseErrorDetail, None)
    ResponseStatus = property(get_ResponseStatus, None)
class TokenBindingKeyType(Enum, Int32):
    Rsa2048 = 0
    EcdsaP256 = 1
    AnyExisting = 2
class WebAuthenticationBroker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.Web.WebAuthenticationBroker'
    @winrt_classmethod
    def AuthenticateAndContinue(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics2, requestUri: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_classmethod
    def AuthenticateWithCallbackUriAndContinue(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics2, requestUri: win32more.Windows.Foundation.Uri, callbackUri: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_classmethod
    def AuthenticateWithCallbackUriContinuationDataAndOptionsAndContinue(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics2, requestUri: win32more.Windows.Foundation.Uri, callbackUri: win32more.Windows.Foundation.Uri, continuationData: win32more.Windows.Foundation.Collections.ValueSet, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions) -> Void: ...
    @winrt_classmethod
    def AuthenticateSilentlyAsync(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics2, requestUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
    @winrt_classmethod
    def AuthenticateSilentlyWithOptionsAsync(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics2, requestUri: win32more.Windows.Foundation.Uri, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
    @winrt_classmethod
    def AuthenticateWithCallbackUriAsync(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions, requestUri: win32more.Windows.Foundation.Uri, callbackUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
    @winrt_classmethod
    def AuthenticateWithoutCallbackUriAsync(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics, options: win32more.Windows.Security.Authentication.Web.WebAuthenticationOptions, requestUri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.WebAuthenticationResult]: ...
    @winrt_classmethod
    def GetCurrentApplicationCallbackUri(cls: win32more.Windows.Security.Authentication.Web.IWebAuthenticationBrokerStatics) -> win32more.Windows.Foundation.Uri: ...
class WebAuthenticationOptions(Enum, UInt32):
    None_ = 0
    SilentMode = 1
    UseTitle = 2
    UseHttpPost = 4
    UseCorporateNetwork = 8
class WebAuthenticationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.Web.IWebAuthenticationResult
    _classid_ = 'Windows.Security.Authentication.Web.WebAuthenticationResult'
    @winrt_mixinmethod
    def get_ResponseData(self: win32more.Windows.Security.Authentication.Web.IWebAuthenticationResult) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ResponseStatus(self: win32more.Windows.Security.Authentication.Web.IWebAuthenticationResult) -> win32more.Windows.Security.Authentication.Web.WebAuthenticationStatus: ...
    @winrt_mixinmethod
    def get_ResponseErrorDetail(self: win32more.Windows.Security.Authentication.Web.IWebAuthenticationResult) -> UInt32: ...
    ResponseData = property(get_ResponseData, None)
    ResponseErrorDetail = property(get_ResponseErrorDetail, None)
    ResponseStatus = property(get_ResponseStatus, None)
class WebAuthenticationStatus(Enum, Int32):
    Success = 0
    UserCancel = 1
    ErrorHttp = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Bluetooth
import win32more.Windows.Devices.Bluetooth.Rfcomm
import win32more.Windows.Devices.Enumeration
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Networking
import win32more.Windows.Networking.Sockets
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IRfcommDeviceService(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService'
    _iid_ = Guid('{ae81ff1f-c5a1-4c40-8c28-f3efd69062f3}')
    @winrt_commethod(6)
    def get_ConnectionHostName(self) -> win32more.Windows.Networking.HostName: ...
    @winrt_commethod(7)
    def get_ConnectionServiceName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ServiceId(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(9)
    def get_ProtectionLevel(self) -> win32more.Windows.Networking.Sockets.SocketProtectionLevel: ...
    @winrt_commethod(10)
    def get_MaxProtectionLevel(self) -> win32more.Windows.Networking.Sockets.SocketProtectionLevel: ...
    @winrt_commethod(11)
    def GetSdpRawAttributesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[UInt32, win32more.Windows.Storage.Streams.IBuffer]]: ...
    @winrt_commethod(12)
    def GetSdpRawAttributesWithCacheModeAsync(self, cacheMode: win32more.Windows.Devices.Bluetooth.BluetoothCacheMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[UInt32, win32more.Windows.Storage.Streams.IBuffer]]: ...
    ConnectionHostName = property(get_ConnectionHostName, None)
    ConnectionServiceName = property(get_ConnectionServiceName, None)
    MaxProtectionLevel = property(get_MaxProtectionLevel, None)
    ProtectionLevel = property(get_ProtectionLevel, None)
    ServiceId = property(get_ServiceId, None)
class IRfcommDeviceService2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService2'
    _iid_ = Guid('{536ced14-ebcd-49fe-bf9f-40efc689b20d}')
    @winrt_commethod(6)
    def get_Device(self) -> win32more.Windows.Devices.Bluetooth.BluetoothDevice: ...
    Device = property(get_Device, None)
class IRfcommDeviceService3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService3'
    _iid_ = Guid('{1c22ace6-dd44-4d23-866d-8f3486ee6490}')
    @winrt_commethod(6)
    def get_DeviceAccessInformation(self) -> win32more.Windows.Devices.Enumeration.DeviceAccessInformation: ...
    @winrt_commethod(7)
    def RequestAccessAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Enumeration.DeviceAccessStatus]: ...
    DeviceAccessInformation = property(get_DeviceAccessInformation, None)
class IRfcommDeviceServiceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics'
    _iid_ = Guid('{a4a149ef-626d-41ac-b253-87ac5c27e28a}')
    @winrt_commethod(6)
    def FromIdAsync(self, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommDeviceService]: ...
    @winrt_commethod(7)
    def GetDeviceSelector(self, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> WinRT_String: ...
class IRfcommDeviceServiceStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics2'
    _iid_ = Guid('{aa8cb1c9-e78d-4be4-8076-0a3d87a0a05f}')
    @winrt_commethod(6)
    def GetDeviceSelectorForBluetoothDevice(self, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetDeviceSelectorForBluetoothDeviceWithCacheMode(self, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice, cacheMode: win32more.Windows.Devices.Bluetooth.BluetoothCacheMode) -> WinRT_String: ...
    @winrt_commethod(8)
    def GetDeviceSelectorForBluetoothDeviceAndServiceId(self, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> WinRT_String: ...
    @winrt_commethod(9)
    def GetDeviceSelectorForBluetoothDeviceAndServiceIdWithCacheMode(self, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId, cacheMode: win32more.Windows.Devices.Bluetooth.BluetoothCacheMode) -> WinRT_String: ...
class IRfcommDeviceServicesResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServicesResult'
    _iid_ = Guid('{3b48388c-7ccf-488e-9625-d259a5732d55}')
    @winrt_commethod(6)
    def get_Error(self) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    @winrt_commethod(7)
    def get_Services(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommDeviceService]: ...
    Error = property(get_Error, None)
    Services = property(get_Services, None)
class IRfcommServiceId(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceId'
    _iid_ = Guid('{22629204-7e02-4017-8136-da1b6a1b9bbf}')
    @winrt_commethod(6)
    def get_Uuid(self) -> Guid: ...
    @winrt_commethod(7)
    def AsShortId(self) -> UInt32: ...
    @winrt_commethod(8)
    def AsString(self) -> WinRT_String: ...
    Uuid = property(get_Uuid, None)
class IRfcommServiceIdStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics'
    _iid_ = Guid('{2a179eba-a975-46e3-b56b-08ffd783a5fe}')
    @winrt_commethod(6)
    def FromUuid(self, uuid: Guid) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(7)
    def FromShortId(self, shortId: UInt32) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(8)
    def get_SerialPort(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(9)
    def get_ObexObjectPush(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(10)
    def get_ObexFileTransfer(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(11)
    def get_PhoneBookAccessPce(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(12)
    def get_PhoneBookAccessPse(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(13)
    def get_GenericFileTransfer(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    GenericFileTransfer = property(get_GenericFileTransfer, None)
    ObexFileTransfer = property(get_ObexFileTransfer, None)
    ObexObjectPush = property(get_ObexObjectPush, None)
    PhoneBookAccessPce = property(get_PhoneBookAccessPce, None)
    PhoneBookAccessPse = property(get_PhoneBookAccessPse, None)
    SerialPort = property(get_SerialPort, None)
class IRfcommServiceProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider'
    _iid_ = Guid('{eadbfdc4-b1f6-44ff-9f7c-e7a82ab86821}')
    @winrt_commethod(6)
    def get_ServiceId(self) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_commethod(7)
    def get_SdpRawAttributes(self) -> win32more.Windows.Foundation.Collections.IMap[UInt32, win32more.Windows.Storage.Streams.IBuffer]: ...
    @winrt_commethod(8)
    def StartAdvertising(self, listener: win32more.Windows.Networking.Sockets.StreamSocketListener) -> Void: ...
    @winrt_commethod(9)
    def StopAdvertising(self) -> Void: ...
    SdpRawAttributes = property(get_SdpRawAttributes, None)
    ServiceId = property(get_ServiceId, None)
class IRfcommServiceProvider2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider2'
    _iid_ = Guid('{736bdfc6-3c81-4d1e-baf2-ddbb81284512}')
    @winrt_commethod(6)
    def StartAdvertisingWithRadioDiscoverability(self, listener: win32more.Windows.Networking.Sockets.StreamSocketListener, radioDiscoverable: Boolean) -> Void: ...
class IRfcommServiceProviderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProviderStatics'
    _iid_ = Guid('{98888303-69ca-413a-84f7-4344c7292997}')
    @winrt_commethod(6)
    def CreateAsync(self, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceProvider]: ...
class RfcommDeviceService(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.RfcommDeviceService'
    @winrt_mixinmethod
    def get_ConnectionHostName(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService) -> win32more.Windows.Networking.HostName: ...
    @winrt_mixinmethod
    def get_ConnectionServiceName(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ServiceId(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_mixinmethod
    def get_ProtectionLevel(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService) -> win32more.Windows.Networking.Sockets.SocketProtectionLevel: ...
    @winrt_mixinmethod
    def get_MaxProtectionLevel(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService) -> win32more.Windows.Networking.Sockets.SocketProtectionLevel: ...
    @winrt_mixinmethod
    def GetSdpRawAttributesAsync(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[UInt32, win32more.Windows.Storage.Streams.IBuffer]]: ...
    @winrt_mixinmethod
    def GetSdpRawAttributesWithCacheModeAsync(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService, cacheMode: win32more.Windows.Devices.Bluetooth.BluetoothCacheMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[UInt32, win32more.Windows.Storage.Streams.IBuffer]]: ...
    @winrt_mixinmethod
    def get_Device(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService2) -> win32more.Windows.Devices.Bluetooth.BluetoothDevice: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_DeviceAccessInformation(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService3) -> win32more.Windows.Devices.Enumeration.DeviceAccessInformation: ...
    @winrt_mixinmethod
    def RequestAccessAsync(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceService3) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Enumeration.DeviceAccessStatus]: ...
    @winrt_classmethod
    def GetDeviceSelectorForBluetoothDevice(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics2, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice) -> WinRT_String: ...
    @winrt_classmethod
    def GetDeviceSelectorForBluetoothDeviceWithCacheMode(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics2, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice, cacheMode: win32more.Windows.Devices.Bluetooth.BluetoothCacheMode) -> WinRT_String: ...
    @winrt_classmethod
    def GetDeviceSelectorForBluetoothDeviceAndServiceId(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics2, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> WinRT_String: ...
    @winrt_classmethod
    def GetDeviceSelectorForBluetoothDeviceAndServiceIdWithCacheMode(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics2, bluetoothDevice: win32more.Windows.Devices.Bluetooth.BluetoothDevice, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId, cacheMode: win32more.Windows.Devices.Bluetooth.BluetoothCacheMode) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommDeviceService]: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServiceStatics, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> WinRT_String: ...
    ConnectionHostName = property(get_ConnectionHostName, None)
    ConnectionServiceName = property(get_ConnectionServiceName, None)
    Device = property(get_Device, None)
    DeviceAccessInformation = property(get_DeviceAccessInformation, None)
    MaxProtectionLevel = property(get_MaxProtectionLevel, None)
    ProtectionLevel = property(get_ProtectionLevel, None)
    ServiceId = property(get_ServiceId, None)
class RfcommDeviceServicesResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServicesResult
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.RfcommDeviceServicesResult'
    @winrt_mixinmethod
    def get_Error(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServicesResult) -> win32more.Windows.Devices.Bluetooth.BluetoothError: ...
    @winrt_mixinmethod
    def get_Services(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommDeviceServicesResult) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommDeviceService]: ...
    Error = property(get_Error, None)
    Services = property(get_Services, None)
class _RfcommServiceId_Meta_(ComPtr.__class__):
    pass
class RfcommServiceId(ComPtr, metaclass=_RfcommServiceId_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceId
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId'
    @winrt_mixinmethod
    def get_Uuid(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceId) -> Guid: ...
    @winrt_mixinmethod
    def AsShortId(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceId) -> UInt32: ...
    @winrt_mixinmethod
    def AsString(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceId) -> WinRT_String: ...
    @winrt_classmethod
    def FromUuid(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics, uuid: Guid) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_classmethod
    def FromShortId(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics, shortId: UInt32) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_classmethod
    def get_SerialPort(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_classmethod
    def get_ObexObjectPush(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_classmethod
    def get_ObexFileTransfer(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_classmethod
    def get_PhoneBookAccessPce(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_classmethod
    def get_PhoneBookAccessPse(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_classmethod
    def get_GenericFileTransfer(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceIdStatics) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    Uuid = property(get_Uuid, None)
    _RfcommServiceId_Meta_.GenericFileTransfer = property(get_GenericFileTransfer, None)
    _RfcommServiceId_Meta_.ObexFileTransfer = property(get_ObexFileTransfer, None)
    _RfcommServiceId_Meta_.ObexObjectPush = property(get_ObexObjectPush, None)
    _RfcommServiceId_Meta_.PhoneBookAccessPce = property(get_PhoneBookAccessPce, None)
    _RfcommServiceId_Meta_.PhoneBookAccessPse = property(get_PhoneBookAccessPse, None)
    _RfcommServiceId_Meta_.SerialPort = property(get_SerialPort, None)
class RfcommServiceProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider
    _classid_ = 'Windows.Devices.Bluetooth.Rfcomm.RfcommServiceProvider'
    @winrt_mixinmethod
    def get_ServiceId(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider) -> win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId: ...
    @winrt_mixinmethod
    def get_SdpRawAttributes(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider) -> win32more.Windows.Foundation.Collections.IMap[UInt32, win32more.Windows.Storage.Streams.IBuffer]: ...
    @winrt_mixinmethod
    def StartAdvertising(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider, listener: win32more.Windows.Networking.Sockets.StreamSocketListener) -> Void: ...
    @winrt_mixinmethod
    def StopAdvertising(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider) -> Void: ...
    @winrt_mixinmethod
    def StartAdvertisingWithRadioDiscoverability(self: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProvider2, listener: win32more.Windows.Networking.Sockets.StreamSocketListener, radioDiscoverable: Boolean) -> Void: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Windows.Devices.Bluetooth.Rfcomm.IRfcommServiceProviderStatics, serviceId: win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceId) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Bluetooth.Rfcomm.RfcommServiceProvider]: ...
    SdpRawAttributes = property(get_SdpRawAttributes, None)
    ServiceId = property(get_ServiceId, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.UI
import win32more.Windows.Foundation
import win32more.Windows.UI
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class ClosableNotifierHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{478cec68-ea8e-52fc-87e2-c819de000f92}')
    @winrt_commethod(3)
    def Invoke(self) -> Void: ...
class ColorHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.IColorHelper
    _classid_ = 'Microsoft.UI.ColorHelper'
    @winrt_classmethod
    def ToDisplayName(cls: win32more.Microsoft.UI.IColorHelperStatics2, color: win32more.Windows.UI.Color) -> WinRT_String: ...
    @winrt_classmethod
    def FromArgb(cls: win32more.Microsoft.UI.IColorHelperStatics, a: Byte, r: Byte, g: Byte, b: Byte) -> win32more.Windows.UI.Color: ...
class _Colors_Meta_(ComPtr.__class__):
    pass
class Colors(ComPtr, metaclass=_Colors_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.IColors
    _classid_ = 'Microsoft.UI.Colors'
    @winrt_classmethod
    def get_AliceBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_AntiqueWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Aqua(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Aquamarine(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Azure(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Beige(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Bisque(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Black(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_BlanchedAlmond(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Blue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_BlueViolet(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Brown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_BurlyWood(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_CadetBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Chartreuse(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Chocolate(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Coral(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_CornflowerBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Cornsilk(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Crimson(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Cyan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkCyan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkGoldenrod(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkKhaki(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkMagenta(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkOliveGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkOrange(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkOrchid(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSalmon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSlateBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSlateGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkTurquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkViolet(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DeepPink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DeepSkyBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DimGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DodgerBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Firebrick(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_FloralWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_ForestGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Fuchsia(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Gainsboro(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_GhostWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Gold(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Goldenrod(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Gray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Green(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_GreenYellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Honeydew(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_HotPink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_IndianRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Indigo(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Ivory(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Khaki(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Lavender(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LavenderBlush(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LawnGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LemonChiffon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightCoral(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightCyan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightGoldenrodYellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightPink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSalmon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSkyBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSlateGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSteelBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightYellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Lime(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LimeGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Linen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Magenta(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Maroon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumAquamarine(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumOrchid(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumPurple(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumSeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumSlateBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumSpringGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumTurquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumVioletRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MidnightBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MintCream(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MistyRose(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Moccasin(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_NavajoWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Navy(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_OldLace(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Olive(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_OliveDrab(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Orange(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_OrangeRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Orchid(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleGoldenrod(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleTurquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleVioletRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PapayaWhip(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PeachPuff(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Peru(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Pink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Plum(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PowderBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Purple(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Red(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_RosyBrown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_RoyalBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SaddleBrown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Salmon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SandyBrown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SeaShell(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Sienna(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Silver(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SkyBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SlateBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SlateGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Snow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SpringGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SteelBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Tan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Teal(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Thistle(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Tomato(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Transparent(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Turquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Violet(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Wheat(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_White(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_WhiteSmoke(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Yellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_YellowGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    _Colors_Meta_.AliceBlue = property(get_AliceBlue, None)
    _Colors_Meta_.AntiqueWhite = property(get_AntiqueWhite, None)
    _Colors_Meta_.Aqua = property(get_Aqua, None)
    _Colors_Meta_.Aquamarine = property(get_Aquamarine, None)
    _Colors_Meta_.Azure = property(get_Azure, None)
    _Colors_Meta_.Beige = property(get_Beige, None)
    _Colors_Meta_.Bisque = property(get_Bisque, None)
    _Colors_Meta_.Black = property(get_Black, None)
    _Colors_Meta_.BlanchedAlmond = property(get_BlanchedAlmond, None)
    _Colors_Meta_.Blue = property(get_Blue, None)
    _Colors_Meta_.BlueViolet = property(get_BlueViolet, None)
    _Colors_Meta_.Brown = property(get_Brown, None)
    _Colors_Meta_.BurlyWood = property(get_BurlyWood, None)
    _Colors_Meta_.CadetBlue = property(get_CadetBlue, None)
    _Colors_Meta_.Chartreuse = property(get_Chartreuse, None)
    _Colors_Meta_.Chocolate = property(get_Chocolate, None)
    _Colors_Meta_.Coral = property(get_Coral, None)
    _Colors_Meta_.CornflowerBlue = property(get_CornflowerBlue, None)
    _Colors_Meta_.Cornsilk = property(get_Cornsilk, None)
    _Colors_Meta_.Crimson = property(get_Crimson, None)
    _Colors_Meta_.Cyan = property(get_Cyan, None)
    _Colors_Meta_.DarkBlue = property(get_DarkBlue, None)
    _Colors_Meta_.DarkCyan = property(get_DarkCyan, None)
    _Colors_Meta_.DarkGoldenrod = property(get_DarkGoldenrod, None)
    _Colors_Meta_.DarkGray = property(get_DarkGray, None)
    _Colors_Meta_.DarkGreen = property(get_DarkGreen, None)
    _Colors_Meta_.DarkKhaki = property(get_DarkKhaki, None)
    _Colors_Meta_.DarkMagenta = property(get_DarkMagenta, None)
    _Colors_Meta_.DarkOliveGreen = property(get_DarkOliveGreen, None)
    _Colors_Meta_.DarkOrange = property(get_DarkOrange, None)
    _Colors_Meta_.DarkOrchid = property(get_DarkOrchid, None)
    _Colors_Meta_.DarkRed = property(get_DarkRed, None)
    _Colors_Meta_.DarkSalmon = property(get_DarkSalmon, None)
    _Colors_Meta_.DarkSeaGreen = property(get_DarkSeaGreen, None)
    _Colors_Meta_.DarkSlateBlue = property(get_DarkSlateBlue, None)
    _Colors_Meta_.DarkSlateGray = property(get_DarkSlateGray, None)
    _Colors_Meta_.DarkTurquoise = property(get_DarkTurquoise, None)
    _Colors_Meta_.DarkViolet = property(get_DarkViolet, None)
    _Colors_Meta_.DeepPink = property(get_DeepPink, None)
    _Colors_Meta_.DeepSkyBlue = property(get_DeepSkyBlue, None)
    _Colors_Meta_.DimGray = property(get_DimGray, None)
    _Colors_Meta_.DodgerBlue = property(get_DodgerBlue, None)
    _Colors_Meta_.Firebrick = property(get_Firebrick, None)
    _Colors_Meta_.FloralWhite = property(get_FloralWhite, None)
    _Colors_Meta_.ForestGreen = property(get_ForestGreen, None)
    _Colors_Meta_.Fuchsia = property(get_Fuchsia, None)
    _Colors_Meta_.Gainsboro = property(get_Gainsboro, None)
    _Colors_Meta_.GhostWhite = property(get_GhostWhite, None)
    _Colors_Meta_.Gold = property(get_Gold, None)
    _Colors_Meta_.Goldenrod = property(get_Goldenrod, None)
    _Colors_Meta_.Gray = property(get_Gray, None)
    _Colors_Meta_.Green = property(get_Green, None)
    _Colors_Meta_.GreenYellow = property(get_GreenYellow, None)
    _Colors_Meta_.Honeydew = property(get_Honeydew, None)
    _Colors_Meta_.HotPink = property(get_HotPink, None)
    _Colors_Meta_.IndianRed = property(get_IndianRed, None)
    _Colors_Meta_.Indigo = property(get_Indigo, None)
    _Colors_Meta_.Ivory = property(get_Ivory, None)
    _Colors_Meta_.Khaki = property(get_Khaki, None)
    _Colors_Meta_.Lavender = property(get_Lavender, None)
    _Colors_Meta_.LavenderBlush = property(get_LavenderBlush, None)
    _Colors_Meta_.LawnGreen = property(get_LawnGreen, None)
    _Colors_Meta_.LemonChiffon = property(get_LemonChiffon, None)
    _Colors_Meta_.LightBlue = property(get_LightBlue, None)
    _Colors_Meta_.LightCoral = property(get_LightCoral, None)
    _Colors_Meta_.LightCyan = property(get_LightCyan, None)
    _Colors_Meta_.LightGoldenrodYellow = property(get_LightGoldenrodYellow, None)
    _Colors_Meta_.LightGray = property(get_LightGray, None)
    _Colors_Meta_.LightGreen = property(get_LightGreen, None)
    _Colors_Meta_.LightPink = property(get_LightPink, None)
    _Colors_Meta_.LightSalmon = property(get_LightSalmon, None)
    _Colors_Meta_.LightSeaGreen = property(get_LightSeaGreen, None)
    _Colors_Meta_.LightSkyBlue = property(get_LightSkyBlue, None)
    _Colors_Meta_.LightSlateGray = property(get_LightSlateGray, None)
    _Colors_Meta_.LightSteelBlue = property(get_LightSteelBlue, None)
    _Colors_Meta_.LightYellow = property(get_LightYellow, None)
    _Colors_Meta_.Lime = property(get_Lime, None)
    _Colors_Meta_.LimeGreen = property(get_LimeGreen, None)
    _Colors_Meta_.Linen = property(get_Linen, None)
    _Colors_Meta_.Magenta = property(get_Magenta, None)
    _Colors_Meta_.Maroon = property(get_Maroon, None)
    _Colors_Meta_.MediumAquamarine = property(get_MediumAquamarine, None)
    _Colors_Meta_.MediumBlue = property(get_MediumBlue, None)
    _Colors_Meta_.MediumOrchid = property(get_MediumOrchid, None)
    _Colors_Meta_.MediumPurple = property(get_MediumPurple, None)
    _Colors_Meta_.MediumSeaGreen = property(get_MediumSeaGreen, None)
    _Colors_Meta_.MediumSlateBlue = property(get_MediumSlateBlue, None)
    _Colors_Meta_.MediumSpringGreen = property(get_MediumSpringGreen, None)
    _Colors_Meta_.MediumTurquoise = property(get_MediumTurquoise, None)
    _Colors_Meta_.MediumVioletRed = property(get_MediumVioletRed, None)
    _Colors_Meta_.MidnightBlue = property(get_MidnightBlue, None)
    _Colors_Meta_.MintCream = property(get_MintCream, None)
    _Colors_Meta_.MistyRose = property(get_MistyRose, None)
    _Colors_Meta_.Moccasin = property(get_Moccasin, None)
    _Colors_Meta_.NavajoWhite = property(get_NavajoWhite, None)
    _Colors_Meta_.Navy = property(get_Navy, None)
    _Colors_Meta_.OldLace = property(get_OldLace, None)
    _Colors_Meta_.Olive = property(get_Olive, None)
    _Colors_Meta_.OliveDrab = property(get_OliveDrab, None)
    _Colors_Meta_.Orange = property(get_Orange, None)
    _Colors_Meta_.OrangeRed = property(get_OrangeRed, None)
    _Colors_Meta_.Orchid = property(get_Orchid, None)
    _Colors_Meta_.PaleGoldenrod = property(get_PaleGoldenrod, None)
    _Colors_Meta_.PaleGreen = property(get_PaleGreen, None)
    _Colors_Meta_.PaleTurquoise = property(get_PaleTurquoise, None)
    _Colors_Meta_.PaleVioletRed = property(get_PaleVioletRed, None)
    _Colors_Meta_.PapayaWhip = property(get_PapayaWhip, None)
    _Colors_Meta_.PeachPuff = property(get_PeachPuff, None)
    _Colors_Meta_.Peru = property(get_Peru, None)
    _Colors_Meta_.Pink = property(get_Pink, None)
    _Colors_Meta_.Plum = property(get_Plum, None)
    _Colors_Meta_.PowderBlue = property(get_PowderBlue, None)
    _Colors_Meta_.Purple = property(get_Purple, None)
    _Colors_Meta_.Red = property(get_Red, None)
    _Colors_Meta_.RosyBrown = property(get_RosyBrown, None)
    _Colors_Meta_.RoyalBlue = property(get_RoyalBlue, None)
    _Colors_Meta_.SaddleBrown = property(get_SaddleBrown, None)
    _Colors_Meta_.Salmon = property(get_Salmon, None)
    _Colors_Meta_.SandyBrown = property(get_SandyBrown, None)
    _Colors_Meta_.SeaGreen = property(get_SeaGreen, None)
    _Colors_Meta_.SeaShell = property(get_SeaShell, None)
    _Colors_Meta_.Sienna = property(get_Sienna, None)
    _Colors_Meta_.Silver = property(get_Silver, None)
    _Colors_Meta_.SkyBlue = property(get_SkyBlue, None)
    _Colors_Meta_.SlateBlue = property(get_SlateBlue, None)
    _Colors_Meta_.SlateGray = property(get_SlateGray, None)
    _Colors_Meta_.Snow = property(get_Snow, None)
    _Colors_Meta_.SpringGreen = property(get_SpringGreen, None)
    _Colors_Meta_.SteelBlue = property(get_SteelBlue, None)
    _Colors_Meta_.Tan = property(get_Tan, None)
    _Colors_Meta_.Teal = property(get_Teal, None)
    _Colors_Meta_.Thistle = property(get_Thistle, None)
    _Colors_Meta_.Tomato = property(get_Tomato, None)
    _Colors_Meta_.Transparent = property(get_Transparent, None)
    _Colors_Meta_.Turquoise = property(get_Turquoise, None)
    _Colors_Meta_.Violet = property(get_Violet, None)
    _Colors_Meta_.Wheat = property(get_Wheat, None)
    _Colors_Meta_.White = property(get_White, None)
    _Colors_Meta_.WhiteSmoke = property(get_WhiteSmoke, None)
    _Colors_Meta_.Yellow = property(get_Yellow, None)
    _Colors_Meta_.YellowGreen = property(get_YellowGreen, None)
class DisplayId(Structure):
    Value: UInt64
class IClosableNotifier(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.IClosableNotifier'
    _iid_ = Guid('{2989e93b-ed0f-5e79-90f2-eac592fc6e6a}')
    @winrt_commethod(6)
    def get_IsClosed(self) -> Boolean: ...
    @winrt_commethod(7)
    def add_Closed(self, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_FrameworkClosed(self, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_FrameworkClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsClosed = property(get_IsClosed, None)
    Closed = event()
    FrameworkClosed = event()
class IColorHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.IColorHelper'
    _iid_ = Guid('{3adddccd-3949-585b-a566-ccb8350dd221}')
class IColorHelperStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.IColorHelperStatics'
    _iid_ = Guid('{1d1d85a1-eb63-538a-84f0-019210bc406b}')
    @winrt_commethod(6)
    def FromArgb(self, a: Byte, r: Byte, g: Byte, b: Byte) -> win32more.Windows.UI.Color: ...
class IColorHelperStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.IColorHelperStatics2'
    _iid_ = Guid('{982a2d93-0ec4-56b7-9c20-0b5c77949066}')
    @winrt_commethod(6)
    def ToDisplayName(self, color: win32more.Windows.UI.Color) -> WinRT_String: ...
class IColors(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.IColors'
    _iid_ = Guid('{8cf15863-8411-5afd-946c-328e04da2f2f}')
class IColorsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.IColorsStatics'
    _iid_ = Guid('{8620a5b0-015a-57ac-a3f3-895d0b1269ae}')
    @winrt_commethod(6)
    def get_AliceBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def get_AntiqueWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(8)
    def get_Aqua(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(9)
    def get_Aquamarine(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(10)
    def get_Azure(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(11)
    def get_Beige(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(12)
    def get_Bisque(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(13)
    def get_Black(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(14)
    def get_BlanchedAlmond(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(15)
    def get_Blue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(16)
    def get_BlueViolet(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(17)
    def get_Brown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(18)
    def get_BurlyWood(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(19)
    def get_CadetBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(20)
    def get_Chartreuse(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(21)
    def get_Chocolate(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(22)
    def get_Coral(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(23)
    def get_CornflowerBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(24)
    def get_Cornsilk(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(25)
    def get_Crimson(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(26)
    def get_Cyan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(27)
    def get_DarkBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(28)
    def get_DarkCyan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(29)
    def get_DarkGoldenrod(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(30)
    def get_DarkGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(31)
    def get_DarkGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(32)
    def get_DarkKhaki(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(33)
    def get_DarkMagenta(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(34)
    def get_DarkOliveGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(35)
    def get_DarkOrange(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(36)
    def get_DarkOrchid(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(37)
    def get_DarkRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(38)
    def get_DarkSalmon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(39)
    def get_DarkSeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(40)
    def get_DarkSlateBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(41)
    def get_DarkSlateGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(42)
    def get_DarkTurquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(43)
    def get_DarkViolet(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(44)
    def get_DeepPink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(45)
    def get_DeepSkyBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(46)
    def get_DimGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(47)
    def get_DodgerBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(48)
    def get_Firebrick(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(49)
    def get_FloralWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(50)
    def get_ForestGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(51)
    def get_Fuchsia(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(52)
    def get_Gainsboro(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(53)
    def get_GhostWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(54)
    def get_Gold(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(55)
    def get_Goldenrod(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(56)
    def get_Gray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(57)
    def get_Green(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(58)
    def get_GreenYellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(59)
    def get_Honeydew(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(60)
    def get_HotPink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(61)
    def get_IndianRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(62)
    def get_Indigo(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(63)
    def get_Ivory(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(64)
    def get_Khaki(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(65)
    def get_Lavender(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(66)
    def get_LavenderBlush(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(67)
    def get_LawnGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(68)
    def get_LemonChiffon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(69)
    def get_LightBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(70)
    def get_LightCoral(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(71)
    def get_LightCyan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(72)
    def get_LightGoldenrodYellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(73)
    def get_LightGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(74)
    def get_LightGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(75)
    def get_LightPink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(76)
    def get_LightSalmon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(77)
    def get_LightSeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(78)
    def get_LightSkyBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(79)
    def get_LightSlateGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(80)
    def get_LightSteelBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(81)
    def get_LightYellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(82)
    def get_Lime(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(83)
    def get_LimeGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(84)
    def get_Linen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(85)
    def get_Magenta(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(86)
    def get_Maroon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(87)
    def get_MediumAquamarine(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(88)
    def get_MediumBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(89)
    def get_MediumOrchid(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(90)
    def get_MediumPurple(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(91)
    def get_MediumSeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(92)
    def get_MediumSlateBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(93)
    def get_MediumSpringGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(94)
    def get_MediumTurquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(95)
    def get_MediumVioletRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(96)
    def get_MidnightBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(97)
    def get_MintCream(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(98)
    def get_MistyRose(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(99)
    def get_Moccasin(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(100)
    def get_NavajoWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(101)
    def get_Navy(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(102)
    def get_OldLace(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(103)
    def get_Olive(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(104)
    def get_OliveDrab(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(105)
    def get_Orange(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(106)
    def get_OrangeRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(107)
    def get_Orchid(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(108)
    def get_PaleGoldenrod(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(109)
    def get_PaleGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(110)
    def get_PaleTurquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(111)
    def get_PaleVioletRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(112)
    def get_PapayaWhip(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(113)
    def get_PeachPuff(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(114)
    def get_Peru(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(115)
    def get_Pink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(116)
    def get_Plum(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(117)
    def get_PowderBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(118)
    def get_Purple(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(119)
    def get_Red(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(120)
    def get_RosyBrown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(121)
    def get_RoyalBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(122)
    def get_SaddleBrown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(123)
    def get_Salmon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(124)
    def get_SandyBrown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(125)
    def get_SeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(126)
    def get_SeaShell(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(127)
    def get_Sienna(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(128)
    def get_Silver(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(129)
    def get_SkyBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(130)
    def get_SlateBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(131)
    def get_SlateGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(132)
    def get_Snow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(133)
    def get_SpringGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(134)
    def get_SteelBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(135)
    def get_Tan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(136)
    def get_Teal(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(137)
    def get_Thistle(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(138)
    def get_Tomato(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(139)
    def get_Transparent(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(140)
    def get_Turquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(141)
    def get_Violet(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(142)
    def get_Wheat(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(143)
    def get_White(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(144)
    def get_WhiteSmoke(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(145)
    def get_Yellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(146)
    def get_YellowGreen(self) -> win32more.Windows.UI.Color: ...
    AliceBlue = property(get_AliceBlue, None)
    AntiqueWhite = property(get_AntiqueWhite, None)
    Aqua = property(get_Aqua, None)
    Aquamarine = property(get_Aquamarine, None)
    Azure = property(get_Azure, None)
    Beige = property(get_Beige, None)
    Bisque = property(get_Bisque, None)
    Black = property(get_Black, None)
    BlanchedAlmond = property(get_BlanchedAlmond, None)
    Blue = property(get_Blue, None)
    BlueViolet = property(get_BlueViolet, None)
    Brown = property(get_Brown, None)
    BurlyWood = property(get_BurlyWood, None)
    CadetBlue = property(get_CadetBlue, None)
    Chartreuse = property(get_Chartreuse, None)
    Chocolate = property(get_Chocolate, None)
    Coral = property(get_Coral, None)
    CornflowerBlue = property(get_CornflowerBlue, None)
    Cornsilk = property(get_Cornsilk, None)
    Crimson = property(get_Crimson, None)
    Cyan = property(get_Cyan, None)
    DarkBlue = property(get_DarkBlue, None)
    DarkCyan = property(get_DarkCyan, None)
    DarkGoldenrod = property(get_DarkGoldenrod, None)
    DarkGray = property(get_DarkGray, None)
    DarkGreen = property(get_DarkGreen, None)
    DarkKhaki = property(get_DarkKhaki, None)
    DarkMagenta = property(get_DarkMagenta, None)
    DarkOliveGreen = property(get_DarkOliveGreen, None)
    DarkOrange = property(get_DarkOrange, None)
    DarkOrchid = property(get_DarkOrchid, None)
    DarkRed = property(get_DarkRed, None)
    DarkSalmon = property(get_DarkSalmon, None)
    DarkSeaGreen = property(get_DarkSeaGreen, None)
    DarkSlateBlue = property(get_DarkSlateBlue, None)
    DarkSlateGray = property(get_DarkSlateGray, None)
    DarkTurquoise = property(get_DarkTurquoise, None)
    DarkViolet = property(get_DarkViolet, None)
    DeepPink = property(get_DeepPink, None)
    DeepSkyBlue = property(get_DeepSkyBlue, None)
    DimGray = property(get_DimGray, None)
    DodgerBlue = property(get_DodgerBlue, None)
    Firebrick = property(get_Firebrick, None)
    FloralWhite = property(get_FloralWhite, None)
    ForestGreen = property(get_ForestGreen, None)
    Fuchsia = property(get_Fuchsia, None)
    Gainsboro = property(get_Gainsboro, None)
    GhostWhite = property(get_GhostWhite, None)
    Gold = property(get_Gold, None)
    Goldenrod = property(get_Goldenrod, None)
    Gray = property(get_Gray, None)
    Green = property(get_Green, None)
    GreenYellow = property(get_GreenYellow, None)
    Honeydew = property(get_Honeydew, None)
    HotPink = property(get_HotPink, None)
    IndianRed = property(get_IndianRed, None)
    Indigo = property(get_Indigo, None)
    Ivory = property(get_Ivory, None)
    Khaki = property(get_Khaki, None)
    Lavender = property(get_Lavender, None)
    LavenderBlush = property(get_LavenderBlush, None)
    LawnGreen = property(get_LawnGreen, None)
    LemonChiffon = property(get_LemonChiffon, None)
    LightBlue = property(get_LightBlue, None)
    LightCoral = property(get_LightCoral, None)
    LightCyan = property(get_LightCyan, None)
    LightGoldenrodYellow = property(get_LightGoldenrodYellow, None)
    LightGray = property(get_LightGray, None)
    LightGreen = property(get_LightGreen, None)
    LightPink = property(get_LightPink, None)
    LightSalmon = property(get_LightSalmon, None)
    LightSeaGreen = property(get_LightSeaGreen, None)
    LightSkyBlue = property(get_LightSkyBlue, None)
    LightSlateGray = property(get_LightSlateGray, None)
    LightSteelBlue = property(get_LightSteelBlue, None)
    LightYellow = property(get_LightYellow, None)
    Lime = property(get_Lime, None)
    LimeGreen = property(get_LimeGreen, None)
    Linen = property(get_Linen, None)
    Magenta = property(get_Magenta, None)
    Maroon = property(get_Maroon, None)
    MediumAquamarine = property(get_MediumAquamarine, None)
    MediumBlue = property(get_MediumBlue, None)
    MediumOrchid = property(get_MediumOrchid, None)
    MediumPurple = property(get_MediumPurple, None)
    MediumSeaGreen = property(get_MediumSeaGreen, None)
    MediumSlateBlue = property(get_MediumSlateBlue, None)
    MediumSpringGreen = property(get_MediumSpringGreen, None)
    MediumTurquoise = property(get_MediumTurquoise, None)
    MediumVioletRed = property(get_MediumVioletRed, None)
    MidnightBlue = property(get_MidnightBlue, None)
    MintCream = property(get_MintCream, None)
    MistyRose = property(get_MistyRose, None)
    Moccasin = property(get_Moccasin, None)
    NavajoWhite = property(get_NavajoWhite, None)
    Navy = property(get_Navy, None)
    OldLace = property(get_OldLace, None)
    Olive = property(get_Olive, None)
    OliveDrab = property(get_OliveDrab, None)
    Orange = property(get_Orange, None)
    OrangeRed = property(get_OrangeRed, None)
    Orchid = property(get_Orchid, None)
    PaleGoldenrod = property(get_PaleGoldenrod, None)
    PaleGreen = property(get_PaleGreen, None)
    PaleTurquoise = property(get_PaleTurquoise, None)
    PaleVioletRed = property(get_PaleVioletRed, None)
    PapayaWhip = property(get_PapayaWhip, None)
    PeachPuff = property(get_PeachPuff, None)
    Peru = property(get_Peru, None)
    Pink = property(get_Pink, None)
    Plum = property(get_Plum, None)
    PowderBlue = property(get_PowderBlue, None)
    Purple = property(get_Purple, None)
    Red = property(get_Red, None)
    RosyBrown = property(get_RosyBrown, None)
    RoyalBlue = property(get_RoyalBlue, None)
    SaddleBrown = property(get_SaddleBrown, None)
    Salmon = property(get_Salmon, None)
    SandyBrown = property(get_SandyBrown, None)
    SeaGreen = property(get_SeaGreen, None)
    SeaShell = property(get_SeaShell, None)
    Sienna = property(get_Sienna, None)
    Silver = property(get_Silver, None)
    SkyBlue = property(get_SkyBlue, None)
    SlateBlue = property(get_SlateBlue, None)
    SlateGray = property(get_SlateGray, None)
    Snow = property(get_Snow, None)
    SpringGreen = property(get_SpringGreen, None)
    SteelBlue = property(get_SteelBlue, None)
    Tan = property(get_Tan, None)
    Teal = property(get_Teal, None)
    Thistle = property(get_Thistle, None)
    Tomato = property(get_Tomato, None)
    Transparent = property(get_Transparent, None)
    Turquoise = property(get_Turquoise, None)
    Violet = property(get_Violet, None)
    Wheat = property(get_Wheat, None)
    White = property(get_White, None)
    WhiteSmoke = property(get_WhiteSmoke, None)
    Yellow = property(get_Yellow, None)
    YellowGreen = property(get_YellowGreen, None)
class IconId(Structure):
    Value: UInt64
class WindowId(Structure):
    Value: UInt64


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.Windows.System
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class _EnvironmentManager_Meta_(ComPtr.__class__):
    pass
class EnvironmentManager(ComPtr, metaclass=_EnvironmentManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.Windows.System.IEnvironmentManager
    _classid_ = 'Microsoft.Windows.System.EnvironmentManager'
    @winrt_mixinmethod
    def GetEnvironmentVariables(self: win32more.Microsoft.Windows.System.IEnvironmentManager) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def GetEnvironmentVariable(self: win32more.Microsoft.Windows.System.IEnvironmentManager, name: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def SetEnvironmentVariable(self: win32more.Microsoft.Windows.System.IEnvironmentManager, name: WinRT_String, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def AppendToPath(self: win32more.Microsoft.Windows.System.IEnvironmentManager, path: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def RemoveFromPath(self: win32more.Microsoft.Windows.System.IEnvironmentManager, path: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def AddExecutableFileExtension(self: win32more.Microsoft.Windows.System.IEnvironmentManager, pathExt: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def RemoveExecutableFileExtension(self: win32more.Microsoft.Windows.System.IEnvironmentManager, pathExt: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_AreChangesTracked(self: win32more.Microsoft.Windows.System.IEnvironmentManager2) -> Boolean: ...
    @winrt_classmethod
    def GetForProcess(cls: win32more.Microsoft.Windows.System.IEnvironmentManagerStatics) -> win32more.Microsoft.Windows.System.EnvironmentManager: ...
    @winrt_classmethod
    def GetForUser(cls: win32more.Microsoft.Windows.System.IEnvironmentManagerStatics) -> win32more.Microsoft.Windows.System.EnvironmentManager: ...
    @winrt_classmethod
    def GetForMachine(cls: win32more.Microsoft.Windows.System.IEnvironmentManagerStatics) -> win32more.Microsoft.Windows.System.EnvironmentManager: ...
    @winrt_classmethod
    def get_IsSupported(cls: win32more.Microsoft.Windows.System.IEnvironmentManagerStatics) -> Boolean: ...
    AreChangesTracked = property(get_AreChangesTracked, None)
    _EnvironmentManager_Meta_.IsSupported = property(get_IsSupported, None)
EnvironmentManagerContract: UInt32 = 131072
class IEnvironmentManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.System.IEnvironmentManager'
    _iid_ = Guid('{d1b239bb-7013-5176-b02a-63477410d986}')
    @winrt_commethod(6)
    def GetEnvironmentVariables(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_commethod(7)
    def GetEnvironmentVariable(self, name: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(8)
    def SetEnvironmentVariable(self, name: WinRT_String, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def AppendToPath(self, path: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def RemoveFromPath(self, path: WinRT_String) -> Void: ...
    @winrt_commethod(11)
    def AddExecutableFileExtension(self, pathExt: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def RemoveExecutableFileExtension(self, pathExt: WinRT_String) -> Void: ...
class IEnvironmentManager2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.System.IEnvironmentManager2'
    _iid_ = Guid('{cfc0ad51-02b7-57ff-8ca7-e015251737cb}')
    @winrt_commethod(6)
    def get_AreChangesTracked(self) -> Boolean: ...
    AreChangesTracked = property(get_AreChangesTracked, None)
class IEnvironmentManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.Windows.System.IEnvironmentManagerStatics'
    _iid_ = Guid('{407b1522-6156-5398-93fd-d6411c35e7b1}')
    @winrt_commethod(6)
    def GetForProcess(self) -> win32more.Microsoft.Windows.System.EnvironmentManager: ...
    @winrt_commethod(7)
    def GetForUser(self) -> win32more.Microsoft.Windows.System.EnvironmentManager: ...
    @winrt_commethod(8)
    def GetForMachine(self) -> win32more.Microsoft.Windows.System.EnvironmentManager: ...
    @winrt_commethod(9)
    def get_IsSupported(self) -> Boolean: ...
    IsSupported = property(get_IsSupported, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.UI.UIAutomation
import win32more.Windows.UI.UIAutomation.Core
import win32more.Windows.Win32.System.WinRT
class AutomationAnnotationTypeRegistration(Structure):
    LocalId: Int32
class AutomationRemoteOperationOperandId(Structure):
    Value: Int32
class AutomationRemoteOperationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.Core.IAutomationRemoteOperationResult
    _classid_ = 'Windows.UI.UIAutomation.Core.AutomationRemoteOperationResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.UI.UIAutomation.Core.IAutomationRemoteOperationResult) -> win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationStatus: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Windows.UI.UIAutomation.Core.IAutomationRemoteOperationResult) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_ErrorLocation(self: win32more.Windows.UI.UIAutomation.Core.IAutomationRemoteOperationResult) -> Int32: ...
    @winrt_mixinmethod
    def HasOperand(self: win32more.Windows.UI.UIAutomation.Core.IAutomationRemoteOperationResult, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> Boolean: ...
    @winrt_mixinmethod
    def GetOperand(self: win32more.Windows.UI.UIAutomation.Core.IAutomationRemoteOperationResult, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    ErrorLocation = property(get_ErrorLocation, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class AutomationRemoteOperationStatus(Enum, Int32):
    Success = 0
    MalformedBytecode = 1
    InstructionLimitExceeded = 2
    UnhandledException = 3
    ExecutionFailure = 4
class CoreAutomationRegistrar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.CoreAutomationRegistrar'
    @winrt_classmethod
    def RegisterAnnotationType(cls: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRegistrarStatics, guid: Guid) -> win32more.Windows.UI.UIAutomation.Core.AutomationAnnotationTypeRegistration: ...
    @winrt_classmethod
    def UnregisterAnnotationType(cls: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRegistrarStatics, registration: win32more.Windows.UI.UIAutomation.Core.AutomationAnnotationTypeRegistration) -> Void: ...
class CoreAutomationRemoteOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation
    _classid_ = 'Windows.UI.UIAutomation.Core.CoreAutomationRemoteOperation'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.UIAutomation.Core.CoreAutomationRemoteOperation.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.UIAutomation.Core.CoreAutomationRemoteOperation: ...
    @winrt_mixinmethod
    def IsOpcodeSupported(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation, opcode: UInt32) -> Boolean: ...
    @winrt_mixinmethod
    def ImportElement(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, element: win32more.Windows.UI.UIAutomation.AutomationElement) -> Void: ...
    @winrt_mixinmethod
    def ImportTextRange(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, textRange: win32more.Windows.UI.UIAutomation.AutomationTextRange) -> Void: ...
    @winrt_mixinmethod
    def AddToResults(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> Void: ...
    @winrt_mixinmethod
    def Execute(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation, bytecodeBuffer: PassArray[Byte]) -> win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationResult: ...
    @winrt_mixinmethod
    def ImportConnectionBoundObject(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation2, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, connectionBoundObject: win32more.Windows.UI.UIAutomation.AutomationConnectionBoundObject) -> Void: ...
class CoreAutomationRemoteOperationContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperationContext
    _classid_ = 'Windows.UI.UIAutomation.Core.CoreAutomationRemoteOperationContext'
    @winrt_mixinmethod
    def GetOperand(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperationContext, id: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def SetOperand(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperationContext, id: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, operand: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SetOperand2(self: win32more.Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperationContext, id: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, operand: win32more.Windows.Win32.System.WinRT.IInspectable, operandInterfaceId: Guid) -> Void: ...
class IAutomationRemoteOperationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.IAutomationRemoteOperationResult'
    _iid_ = Guid('{e0f80c42-4a67-5534-bf5a-09e8a99b36b1}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationStatus: ...
    @winrt_commethod(7)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(8)
    def get_ErrorLocation(self) -> Int32: ...
    @winrt_commethod(9)
    def HasOperand(self, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> Boolean: ...
    @winrt_commethod(10)
    def GetOperand(self, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    ErrorLocation = property(get_ErrorLocation, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class ICoreAutomationConnectionBoundObjectProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.ICoreAutomationConnectionBoundObjectProvider'
    _iid_ = Guid('{0620bb64-9616-5593-be3a-eb8e6daeb3fa}')
    @winrt_commethod(6)
    def get_IsComThreadingRequired(self) -> Boolean: ...
    IsComThreadingRequired = property(get_IsComThreadingRequired, None)
class ICoreAutomationRegistrarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.ICoreAutomationRegistrarStatics'
    _iid_ = Guid('{3e50129b-d6dc-5680-b580-ffff78300304}')
    @winrt_commethod(6)
    def RegisterAnnotationType(self, guid: Guid) -> win32more.Windows.UI.UIAutomation.Core.AutomationAnnotationTypeRegistration: ...
    @winrt_commethod(7)
    def UnregisterAnnotationType(self, registration: win32more.Windows.UI.UIAutomation.Core.AutomationAnnotationTypeRegistration) -> Void: ...
class ICoreAutomationRemoteOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation'
    _iid_ = Guid('{3ac656f4-e2bc-5c6e-b8e7-b224fb74b060}')
    @winrt_commethod(6)
    def IsOpcodeSupported(self, opcode: UInt32) -> Boolean: ...
    @winrt_commethod(7)
    def ImportElement(self, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, element: win32more.Windows.UI.UIAutomation.AutomationElement) -> Void: ...
    @winrt_commethod(8)
    def ImportTextRange(self, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, textRange: win32more.Windows.UI.UIAutomation.AutomationTextRange) -> Void: ...
    @winrt_commethod(9)
    def AddToResults(self, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> Void: ...
    @winrt_commethod(10)
    def Execute(self, bytecodeBuffer: PassArray[Byte]) -> win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationResult: ...
class ICoreAutomationRemoteOperation2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperation2'
    _iid_ = Guid('{eefaf86f-e953-5099-8ce9-dca813482ba0}')
    @winrt_commethod(6)
    def ImportConnectionBoundObject(self, operandId: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, connectionBoundObject: win32more.Windows.UI.UIAutomation.AutomationConnectionBoundObject) -> Void: ...
class ICoreAutomationRemoteOperationContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperationContext'
    _iid_ = Guid('{b9af9cbb-3d3e-5918-a16b-7861626a3aeb}')
    @winrt_commethod(6)
    def GetOperand(self, id: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def SetOperand(self, id: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, operand: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def SetOperand2(self, id: win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId, operand: win32more.Windows.Win32.System.WinRT.IInspectable, operandInterfaceId: Guid) -> Void: ...
class ICoreAutomationRemoteOperationExtensionProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.ICoreAutomationRemoteOperationExtensionProvider'
    _iid_ = Guid('{88f53e67-dc69-553b-a0aa-70477e724da8}')
    @winrt_commethod(6)
    def CallExtension(self, extensionId: Guid, context: win32more.Windows.UI.UIAutomation.Core.CoreAutomationRemoteOperationContext, operandIds: PassArray[win32more.Windows.UI.UIAutomation.Core.AutomationRemoteOperationOperandId]) -> Void: ...
    @winrt_commethod(7)
    def IsExtensionSupported(self, extensionId: Guid) -> Boolean: ...
class IRemoteAutomationClientSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession'
    _iid_ = Guid('{5c8a091d-94cc-5b33-afdb-678cded2bd54}')
    @winrt_commethod(6)
    def Start(self) -> Void: ...
    @winrt_commethod(7)
    def Stop(self) -> Void: ...
    @winrt_commethod(8)
    def CreateWindowAsync(self, remoteWindowId: UInt64, remoteProcessId: UInt32, parentAutomationElement: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.UIAutomation.Core.RemoteAutomationWindow]: ...
    @winrt_commethod(9)
    def get_SessionId(self) -> Guid: ...
    @winrt_commethod(10)
    def add_ConnectionRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession, win32more.Windows.UI.UIAutomation.Core.RemoteAutomationConnectionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_ConnectionRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_Disconnected(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession, win32more.Windows.UI.UIAutomation.Core.RemoteAutomationDisconnectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_Disconnected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SessionId = property(get_SessionId, None)
    ConnectionRequested = event()
    Disconnected = event()
class IRemoteAutomationClientSessionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.IRemoteAutomationClientSessionFactory'
    _iid_ = Guid('{f250263d-6057-5373-a5a5-ed7265fe0376}')
    @winrt_commethod(6)
    def CreateInstance(self, name: WinRT_String) -> win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession: ...
    @winrt_commethod(7)
    def CreateInstance2(self, name: WinRT_String, sessionId: Guid) -> win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession: ...
class IRemoteAutomationConnectionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.IRemoteAutomationConnectionRequestedEventArgs'
    _iid_ = Guid('{ea3319a8-e3a8-5dc6-adf8-044e46b14af5}')
    @winrt_commethod(6)
    def get_LocalPipeName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_RemoteProcessId(self) -> UInt32: ...
    LocalPipeName = property(get_LocalPipeName, None)
    RemoteProcessId = property(get_RemoteProcessId, None)
class IRemoteAutomationDisconnectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.IRemoteAutomationDisconnectedEventArgs'
    _iid_ = Guid('{bbb33a3d-5d90-5c38-9eb2-dd9dcc1b2e3f}')
    @winrt_commethod(6)
    def get_LocalPipeName(self) -> WinRT_String: ...
    LocalPipeName = property(get_LocalPipeName, None)
class IRemoteAutomationServerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.IRemoteAutomationServerStatics'
    _iid_ = Guid('{e6e8945e-0c11-5028-9ae3-c2771288b6b7}')
    @winrt_commethod(6)
    def ReportSession(self, sessionId: Guid) -> Void: ...
class IRemoteAutomationWindow(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.IRemoteAutomationWindow'
    _iid_ = Guid('{7c607689-496d-512a-9bd5-c050cfaf1428}')
    @winrt_commethod(6)
    def get_AutomationProvider(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def UnregisterAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    AutomationProvider = property(get_AutomationProvider, None)
class RemoteAutomationClientSession(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession
    _classid_ = 'Windows.UI.UIAutomation.Core.RemoteAutomationClientSession'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession.CreateInstance(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession.CreateInstance2(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSessionFactory, name: WinRT_String) -> win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession: ...
    @winrt_factorymethod
    def CreateInstance2(cls: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSessionFactory, name: WinRT_String, sessionId: Guid) -> win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession) -> Void: ...
    @winrt_mixinmethod
    def CreateWindowAsync(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession, remoteWindowId: UInt64, remoteProcessId: UInt32, parentAutomationElement: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.UIAutomation.Core.RemoteAutomationWindow]: ...
    @winrt_mixinmethod
    def get_SessionId(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession) -> Guid: ...
    @winrt_mixinmethod
    def add_ConnectionRequested(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession, win32more.Windows.UI.UIAutomation.Core.RemoteAutomationConnectionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ConnectionRequested(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Disconnected(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.UIAutomation.Core.RemoteAutomationClientSession, win32more.Windows.UI.UIAutomation.Core.RemoteAutomationDisconnectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Disconnected(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationClientSession, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SessionId = property(get_SessionId, None)
    ConnectionRequested = event()
    Disconnected = event()
class RemoteAutomationConnectionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationConnectionRequestedEventArgs
    _classid_ = 'Windows.UI.UIAutomation.Core.RemoteAutomationConnectionRequestedEventArgs'
    @winrt_mixinmethod
    def get_LocalPipeName(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationConnectionRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_RemoteProcessId(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationConnectionRequestedEventArgs) -> UInt32: ...
    LocalPipeName = property(get_LocalPipeName, None)
    RemoteProcessId = property(get_RemoteProcessId, None)
class RemoteAutomationDisconnectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationDisconnectedEventArgs
    _classid_ = 'Windows.UI.UIAutomation.Core.RemoteAutomationDisconnectedEventArgs'
    @winrt_mixinmethod
    def get_LocalPipeName(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationDisconnectedEventArgs) -> WinRT_String: ...
    LocalPipeName = property(get_LocalPipeName, None)
class RemoteAutomationServer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.Core.RemoteAutomationServer'
    @winrt_classmethod
    def ReportSession(cls: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationServerStatics, sessionId: Guid) -> Void: ...
class RemoteAutomationWindow(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationWindow
    _classid_ = 'Windows.UI.UIAutomation.Core.RemoteAutomationWindow'
    @winrt_mixinmethod
    def get_AutomationProvider(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationWindow) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def UnregisterAsync(self: win32more.Windows.UI.UIAutomation.Core.IRemoteAutomationWindow) -> win32more.Windows.Foundation.IAsyncAction: ...
    AutomationProvider = property(get_AutomationProvider, None)


make_ready(__name__)
